@@ -1,5 +1,5 @@
 ######################################################################
-# $Id: BaseCacheTester.pm,v 1.3 2001/04/08 22:48:37 dclinton Exp $
+# $Id: BaseCacheTester.pm,v 1.6 2001/12/09 17:00:35 dclinton Exp $
 # Copyright (C) 2001 DeWitt Clinton  All Rights Reserved
 #
 # Software distributed under the License is distributed on an "AS
@@ -13,12 +13,6 @@ package Cache::BaseCacheTester;
 
 
 use strict;
-use Carp;
-
-
-##
-# Constructor
-##
 
 
 sub new
@@ -36,11 +30,6 @@ sub new
 }
 
 
-##
-# Public instance methods
-##
-
-
 sub ok
 {
   my ( $self ) = @_;
@@ -77,11 +66,6 @@ sub skip
 }
 
 
-##
-# Instance properties
-##
-
-
 sub _set_test_count
 {
   my ( $self, $test_count ) = @_;
@@ -137,20 +121,12 @@ class that will test cache implementations.
 
 =head1 METHODS
 
-=over 4
+=over
 
 =item B<new( $base_test_count )>
 
 Construct a new BaseCacheTester and initialize the test count to
-'base_test_count'
-
-=over 4
-
-=item $base_test_count
-
-The initial test count
-
-=back
+I<$base_test_count>.
 
 =item B<ok( )>
 
@@ -159,30 +135,14 @@ incremements the test count.
 
 =item B<not_ok( $message )>
 
-Print a message to stdout in the form "not ok $test_count # $message "
+Print a message to stdout in the form "not ok $test_count # I<$message> "
 and incremements the test count.
 
-=over 4
-
-=item $message
-
-The reason the test failed
-
-=back
-
 =item B<skip( $message )>
 
-Print a message to stdout in the form "ok $test_count # skipped $message "
+Print a message to stdout in the form "ok $test_count # skipped I<$message> "
 and incremements the test count.
 
-=over 4
-
-=item $message
-
-The reason the test was skipped
-
-=back
-
 =back
 
 =head1 SEE ALSO
