@@ -1,5 +1,5 @@
 ######################################################################
-# $Id: SizeAwareCache.pm,v 1.3 2001/09/05 14:39:27 dclinton Exp $
+# $Id: SizeAwareCache.pm,v 1.8 2001/12/09 23:40:52 dclinton Exp $
 # Copyright (C) 2001 DeWitt Clinton  All Rights Reserved
 #
 # Software distributed under the License is distributed on an "AS
@@ -14,57 +14,22 @@ package Cache::SizeAwareCache;
 
 use strict;
 use Cache::Cache;
-use vars qw( @ISA
-             @EXPORT_OK
-             $EXPIRES_NOW
-             $EXPIRES_NEVER
-             $TRUE
-             $FALSE
-             $SUCCESS
-             $FAILURE
-             $NO_MAX_SIZE );
+use vars qw( @ISA @EXPORT_OK $EXPIRES_NOW $EXPIRES_NEVER $NO_MAX_SIZE );
 use Exporter;
 
-
 @ISA = qw( Cache::Cache Exporter );
 
-@EXPORT_OK = qw( $EXPIRES_NOW
-                 $EXPIRES_NEVER
-                 $TRUE
-                 $FALSE
-                 $SUCCESS
-                 $FAILURE
-                 $NO_MAX_SIZE );
-
-
-use vars @EXPORT_OK;
-
+@EXPORT_OK = qw( $EXPIRES_NOW $EXPIRES_NEVER $NO_MAX_SIZE );
 
 $EXPIRES_NOW = $Cache::Cache::EXPIRES_NOW;
 $EXPIRES_NEVER = $Cache::Cache::EXPIRES_NEVER;
-$TRUE = $Cache::Cache::TRUE;
-$FALSE = $Cache::Cache::FALSE;
-$SUCCESS = $Cache::Cache::SUCCESS;
-$FAILURE = $Cache::Cache::FAILURE;
 $NO_MAX_SIZE = -1;
 
 
-##
-# Public instance methods
-##
-
-
 sub limit_size;
 
-
-##
-# Properties
-##
-
-
 sub get_max_size;
 
-
 sub set_max_size;
 
 
@@ -86,7 +51,6 @@ The SizeAwareCache interface is implemented by classes that support
 all of the Cache::Cache interface in addition to the limit_size and
 max_size features of a size aware cache.
 
-
 =head1 SYNOPSIS
 
   use Cache::SizeAwareCache;
@@ -94,14 +58,13 @@ max_size features of a size aware cache.
 
   @ISA = qw( Cache::SizeAwareCache );
 
-
 =head1 CONSTANTS
 
 Please see Cache::Cache for standard constants
 
-=over 4
+=over
 
-=item $NO_MAX_SIZE
+=item I<$NO_MAX_SIZE>
 
 The cache has no size restrictions
 
@@ -109,41 +72,31 @@ The cache has no size restrictions
 
 =head1 METHODS
 
-Please see Cache::Cache for standard methods
+Please see Cache::Cache for the standard methods
 
-=over 4
+=over
 
 =item B<limit_size( $new_size )>
 
 Attempt to resize the cache such that the total disk usage is under
-the 'new_size' parameter.
-
-=over 4
-
-=item $new_size
-
-The size (in bytes) that the cache should be limited to.  This is
-only a one time adjustment.  To maintain the cache size, consider using
-the 'max_size' option, although it is considered very expensive.
-
-=item Returns
-
-Either $SUCCESS or $FAILURE
-
-=back
+the I<$new_size> parameter.  I<$new_size> represents t size (in bytes)
+that the cache should be limited to.  Note that this is only a one
+time adjustment.  To maintain the cache size, consider using the
+I<max_size> option, although it is considered very expensive, and can
+often be better achieved by peridocally calling I<limit_size>.
 
 =back
 
 =head1 OPTIONS
 
-Please see Cache::Cache for standard options
+Please see Cache::Cache for the standard options
 
-=over 4
+=over
 
-=item max_size
+=item I<max_size>
 
 Sets the max_size property (size in bytes), which is described in
-detail below.  Defaults to $NO_MAX_SIZE.
+detail below.  Defaults to I<$NO_MAX_SIZE>.
 
 =back
 
@@ -151,7 +104,7 @@ detail below.  Defaults to $NO_MAX_SIZE.
 
 Please see Cache::Cache for standard properties
 
-=over 4
+=over
 
 =item B<(get|set)_max_size>
 
